==> nextcloud-11.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/it.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Attività",
    "Error loading activities" : "Errore durante il caricamento delle attività",
    "No activities" : "Nessuna attività",
    "Load more activities" : "Carica altre attività",
    "Copied!" : "Copiato!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (limitato)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Questo flusso mostrerà gli eventi come aggiunte, cambiamenti e condivisioni",
    "There are no events for this filter" : "Non ci sono eventi per questo filtro",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "Activity" : "Attività",
    "Personal activity feed for %s" : "Fonte delle attività personali per %s",
    "Your feed URL is invalid" : "L'URL della fonte non è valido",
    "Your settings have been updated." : "Le tue impostazioni sono state aggiornate.",
    "Mail" : "Posta",
    "Stream" : "Flusso",
    "All activities" : "Tutte le attività",
    "By others" : "Di altri",
    "By you" : "Tue",
    "\"remote user\"" : "\"utente remoto\"",
    "Activity notification" : "Notifica delle attività",
    ", " : ", ",
    "%s and %s" : "%s e %s",
    "Hello %s," : "Ciao %s,",
    "You are receiving this email because the following things happened at %s" : "Hai ricevuto questa email perché si sono verificati i seguenti eventi su %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* e %n altra","* e %n altre"],
    "List your own actions in the stream" : "Elenca le tue azioni nel flusso",
    "Notify about your own actions via email" : "Notificami le tue azioni tramite email",
    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo del tuo utente prima di poter ricevere le email di notifica.",
    "Send emails:" : "Invio email:",
    "Hourly" : "Ogni ora",
    "Daily" : "Quotidiano",
    "Weekly" : "Settimanale",
    "Activity feed" : "Fonte delle attività",
    "Enable RSS feed" : "Abilita fonte RSS",
    "No activity yet" : "Ancora nessuna attività",
    "No more events to load" : "Non ci sono altri eventi da caricare",
    "Files" : "File"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/it.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Attività",
    "An error occurred while loading activities" : "E' avvenuto un errore durante il caricamento delle attività",
    "No activity yet" : "Ancora nessuna attività",
    "Load more activities" : "Carica altre attività",
    "Copied!" : "Copiato!",
    "Not supported!" : "Non supportato!",
    "Press ⌘-C to copy." : "Premi ⌘-C per copiare.",
    "Press Ctrl-C to copy." : "Premi Ctrl-C per copiare.",
    "{name} (invisible)" : "{name} (invisibile)",
    "{name} (restricted)" : "{name} (limitato)",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "Questo flusso mostrerà gli eventi come aggiunte, cambiamenti e condivisioni",
    "There are no events for this filter" : "Non ci sono eventi per questo filtro",
    "Today" : "Oggi",
    "Yesterday" : "Ieri",
    "Personal activity feed for %s" : "Fonte delle attività personali per %s",
    "Your feed URL is invalid" : "L'URL della fonte non è valido",
    "Your settings have been updated." : "Le tue impostazioni sono state aggiornate.",
    "Settings have been updated." : "Le impostazioni sono state aggiornate.",
    "Mail" : "Posta",
    "Stream" : "Flusso",
    "All activities" : "Tutte le attività",
    "By others" : "Di altri",
    "By you" : "Tue",
    "\"remote user\"" : "\"utente remoto\"",
    "Hello %s" : "Ciao %s",
    "Hello %s," : "Ciao %s,",
    "There was some activity at %s" : "Attività registrata su %s",
    "Activity notification" : "Notifica delle attività",
    ", " : ", ",
    "%s and %s" : "%s e %s",
    "Activity" : "Attività",
    "Activity feed" : "Fonte delle attività",
    "Configure the default activity settings for new users." : "Configura per i nuovi utenti le impostazioni di default delle attività",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Scegli per quali attività desideri ricevere un email di notifica, e quali devono essere mostrate nel flusso dell'app delle attività",
    "List your own actions in the stream" : "Elenca le tue azioni nel flusso",
    "Notify about your own actions via email" : "Notifica le tue azioni tramite email",
    "You need to set up your email address before you can receive notification emails." : "Devi impostare l'indirizzo del tuo utente prima di poter ricevere le email di notifica.",
    "Send emails:" : "Invio email:",
    "Hourly" : "Ogni ora",
    "Daily" : "Quotidiano",
    "Weekly" : "Settimanale",
    "Settings" : "Impostazioni",
    "Enable RSS feed" : "Abilita fonte RSS",
    "No more events to load" : "Non ci sono altri eventi da caricare",
    "Files" : "File"
},
"nplurals=2; plural=(n != 1);");
